import json
from django.forms.widgets import Input
from django.template import loader
from django.utils.safestring import mark_safe


class MultiImagesInputWidget(Input):
    template_name = 'admin/widgets/img_multi_upload.html'
    input_type = "file"

    class Media:
        css = {
            "all": (
                "css/imgwidget.css",
            )
        }

    def render(self, name, value, attrs=None, renderer=None):
        context = self.get_context(name, value, attrs)
        try:
            context["widget"]['widget_img_urls'] = ",".join(json.loads(value))
        except:
            pass
        template = loader.get_template(self.template_name).render(context)
        return mark_safe(template)


def get_imgs_value(value):
    if not value:
        return []
    values = value.split(',')
    return [value for value in values if value]



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

long_description = "\n".join([
    open('README.md', 'r', encoding='utf-8').read(),
])

NAME = 'django-imgwidget'
VERSION = '0.0.2'

setup(
    name=NAME,
    version=VERSION,
    packages=find_packages(
        exclude=()
    ),
    zip_safe=False,
    include_package_data=True,
    keywords='django,admin,widget,image,uploader',
    url='https://github.com/RelaxedDong/django_imguploder',
    license='Apache License 2.0',
    author='donghao',
    long_description=long_description,
    long_description_content_type="text/markdown",  # 描述文档README的格式 一般md
    author_email='1417766861@qq.com',
    description='上传图片组件',
    install_requires=['django'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
